self.__BUILD_MANIFEST=function(s,a,e,c,t,p,d,i){return{__rewrites:{beforeFiles:[],afterFiles:[],fallback:[]},"/":[s,a,"static/chunks/pages/index-d83bc7f545a73fd0.js"],"/_error":["static/chunks/pages/_error-1995526792b513b2.js"],"/app/bridges/openon":[s,a,e,c,t,p,"static/chunks/pages/app/bridges/openon-03277b88197dfb16.js"],"/app/bridges/setup":[s,a,e,c,t,d,"static/chunks/203-bd4a7b1659a8cb5d.js","static/chunks/pages/app/bridges/setup-2441b528da463b55.js"],"/app/data":[s,"static/chunks/29107295-fbcfe2172188e46f.js",a,e,"static/chunks/398-a2848123c32ae619.js",i,"static/chunks/pages/app/data-21baea60c92cf8aa.js"],"/app/settings":[s,a,e,c,p,d,"static/chunks/807-87d097b8b679fcde.js",i,"static/chunks/pages/app/settings-7c12144b1a902cb8.js"],sortedPages:["/","/_app","/_error","/app/bridges/openon","/app/bridges/setup","/app/data","/app/settings"]}}("static/chunks/b2e984c5-af5b37b6e5a5729b.js","static/chunks/964-4dc83d6aa79c6fa1.js","static/chunks/524-21edcafdcdbab568.js","static/chunks/301-457f75ec7a261a67.js","static/chunks/669-648cde9357302f09.js","static/chunks/545-3c37f9197a262bfa.js","static/chunks/257-17b7924f7bd194f3.js","static/chunks/471-7f4dc278157a809c.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();